GeoHash class

A containing class for a geohash

Constructors

GeoHash(String _geohash)
Constructor given a String geohash
GeoHash.fromDecimalDegrees(double longitude, double latitude, {int precision = 9})
Constructor given Longitude and Latitude

Properties

geohash → String
Returns the String geohash
no setter
hashCode → int
The hash code for this object.
no setterinherited
neighbors → Map<String, String>
Returns a Map<String, String> containing the Direction as the key and the value being the geohash of the neighboring geohash in that direction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String geohash) → bool
Returns true if the given geohash is contained within this geohash
isInside(String geohash) → bool
Returns true if the given geohash contains this one within it.
isNeighbor(String geohash) → bool
Returns true if given geohash is equal to or is a neighbor of this one.
latitude({int? decimalAccuracy}) → double
Returns the double latitude with an optional decimal accuracy
longitude({int? decimalAccuracy}) → double
Returns the double longitude with an optional decimal accuracy
neighbor(Direction direction) → String
Returns a String geohash of a neighboring geohash in a given direction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parent() → GeoHash
Returns a new Geohash for the parent of this one.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited